package node

import (
	"net/http"

	"github.com/prometheus/client_golang/prometheus"
	"github.com/prometheus/client_golang/prometheus/promhttp"
)

var (
	streamSentBytes = prometheus.NewCounterVec(
		prometheus.CounterOpts{
			Name: "bytes_sent",
			Help: "Bytes proxied to the client, by stream.",
		},
		[]string{"stream"},
	)
	streamRcvdBytes = prometheus.NewCounterVec(
		prometheus.CounterOpts{
			Name: "bytes_received",
			Help: "Bytes received from the client, by stream.",
		},
		[]string{"stream"},
	)
	streamListeners = prometheus.NewGaugeVec(
		prometheus.GaugeOpts{
			Name: "listeners",
			Help: "Number of current listeners.",
		},
		[]string{"stream"},
	)
	proxyConnectErrs = prometheus.NewCounterVec(
		prometheus.CounterOpts{
			Name: "proxy_connect_errors",
			Help: "Proxy connection errors (client-side).",
		},
		[]string{"stream", "upstream"},
	)
)

func init() {
	prometheus.MustRegister(
		streamSentBytes,
		streamRcvdBytes,
		streamListeners,
		proxyConnectErrs,
	)
}

func newMetricsHandler() http.Handler {
	mux := http.NewServeMux()
	mux.Handle("/metrics", promhttp.Handler())
	return mux
}
